<?php
/**
 * 2013-2019 Code Plus | Soluciones Informáticas Integrales
 *
 * NOTICE OF LICENSE
 *
 * @author    Code Plus | Soluciones Informáticas Integrales <info@codeplus.es>
 * @copyright 2013-2019 Code Plus | Soluciones Informáticas Integrales
 * @license   GNU General Public License version 2
 *
 * You can not resell or redistribute this software.
 */

if (!defined('_PS_VERSION_')) {
    exit;
}

class Cpsimplecookie extends Module
{
    protected $config_form = false;

    public function __construct()
    {
        $this->name = 'cpsimplecookie';
        $this->tab = 'administration';
        $this->version = '1.2.0';
        $this->author = 'Code Plus | Soluciones Informáticas Integrales';
        $this->need_instance = 1;
        $this->bootstrap = true;
        parent::__construct();
        $this->displayName = $this->l('Code Plus | Simple Cookie');
        $this->description = $this->l('Displays a cookie alert message');
        $this->ps_versions_compliancy = array('min' => '1.6', 'max' => _PS_VERSION_);
        $this->module_key = 'b019e25348ab8619fd81ff28ebb645dd';
    }

    public function install()
    {
        Configuration::updateValue('CPSIMPLECOOKIE_MESSAGE', $this->l('We use our own and third-party cookies to obtain statistical data on the navigation of our users and improve our services. If you accept or continue browsing, we consider that you accept its use. You can change the configuration or get more information here ({link} to cookie page).'));
        Configuration::updateValue('CPSIMPLECOOKIE_SUBMIT', $this->l('Accept'));
        Configuration::updateValue('CPSIMPLECOOKIE_LINK', '1');

        return parent::install() && $this->registerHook('header');
    }

    public function uninstall()
    {
        Configuration::deleteByName('CPSIMPLECOOKIE_MESSAGE');
        Configuration::deleteByName('CPSIMPLECOOKIE_SUBMIT');
        Configuration::deleteByName('CPSIMPLECOOKIE_LINK');

        return parent::uninstall();
    }

    public function getContent()
    {
    	$output = '';
        
        if (((bool)Tools::isSubmit('submitCpSimpleCookie')) == true) {
            $this->postProcess();
            $output .= $this->displayConfirmation($this->l('Saved'));
        }

        return $output.$this->renderForm();

        
    }

    protected function renderForm()
    {
        $helper = new HelperForm();

        $helper->show_toolbar = false;
        $helper->table = $this->table;
        $helper->module = $this;
        $helper->default_form_language = $this->context->language->id;
        $helper->allow_employee_form_lang = Configuration::get('PS_BO_ALLOW_EMPLOYEE_FORM_LANG', 0);

        $helper->identifier = $this->identifier;
        $helper->submit_action = 'submitCpSimpleCookie';
        $helper->currentIndex = $this->context->link->getAdminLink('AdminModules', false)
            .'&configure='.$this->name.'&tab_module='.$this->tab.'&module_name='.$this->name;
        $helper->token = Tools::getAdminTokenLite('AdminModules');

        $helper->tpl_vars = array(
            'fields_value' => $this->getConfigFormValues(),
            'languages' => $this->context->controller->getLanguages(),
            'id_language' => $this->context->language->id,
        );

        return $helper->generateForm(array($this->getConfigForm()));
    }

    protected function getConfigForm()
    {
        return array(
            'form' => array(
                'legend' => array(
                'title' => $this->l('Settings'),
                'icon' => 'icon-cogs',
                ),
                'input' => array(
                    array(
                        'col' => 3,
                        'type' => 'textarea',
                        'name' => 'CPSIMPLECOOKIE_MESSAGE',
                        'label' => $this->l('Message'),
                        'desc' => $this->l('To enter the link to the Cookies Page, type {link}'),
                    ),
                    array(
                        'type' => 'select',
                        'label' => $this->l('Link'),
                        'name' => 'CPSIMPLECOOKIE_LINK',
                        'required' => false,
                        'desc' => $this->l('Link that is inserted in the {link} tag'),
                        'options' => array(
                            'query' => CMS::listCms(),
                            'id' => 'id_cms',
                            'name' => 'meta_title'
                        )
                    ),
                    array(
                        'col' => 2,
                        'type' => 'text',
                        'name' => 'CPSIMPLECOOKIE_SUBMIT',
                        'label' => $this->l('Submit label'),
                    )
                ),
                'submit' => array(
                    'title' => $this->l('Save'),
                ),
            ),
        );
    }

    protected function getConfigFormValues()
    {
        return array(
            'CPSIMPLECOOKIE_MESSAGE' => Configuration::get('CPSIMPLECOOKIE_MESSAGE'),
            'CPSIMPLECOOKIE_SUBMIT' => Configuration::get('CPSIMPLECOOKIE_SUBMIT'),
            'CPSIMPLECOOKIE_LINK' => Configuration::get('CPSIMPLECOOKIE_LINK')
        );
    }

    protected function postProcess()
    {
        $form_values = $this->getConfigFormValues();

        foreach (array_keys($form_values) as $key) {
           	Configuration::updateValue($key, Tools::getValue($key));
       	}
    }

    public function hookHeader()
    {   
        $context = Context::getContext();

        //if ((!isset($context->cookie->showMsg)) || isset($context->cookie->showMsg) && (bool) $context->cookie->showMsg !== true) {
        if ((!isset($_COOKIE['showMsg'])) || isset($_COOKIE['showMsg']) && (bool) $_COOKIE['showMsg'] !== true) {
            $this->context->controller->addCSS($this->_path.'views/css/front.css');
            $this->context->controller->addJS($this->_path.'views/js/front.js');
            $message = '';
            $submit = '';
            $cms_link = '';
            $cms_name = '';

            $cms_link = $context->link->getCMSLink((int) Configuration::get('CPSIMPLECOOKIE_LINK'));
            foreach (CMS::listCms($context->language->id) as $cms_page) {
                if ((int) $cms_page['id_cms'] == (int) Configuration::get('CPSIMPLECOOKIE_LINK')) {
                    $cms_name = $cms_page['meta_title'];
                }
            }

            $this->context->smarty->assign(array(
                'message' => str_replace('{link}', '<a href="'.$cms_link.'">'.$cms_name.'</a>', $this->l(Configuration::get('CPSIMPLECOOKIE_MESSAGE'), 'cpsimplecookie')),
                'submit' => Configuration::get('CPSIMPLECOOKIE_SUBMIT'),
                )
            );

            return $this->context->smarty->fetch($this->local_path.'views/templates/front/alert_cookie.tpl');
        }
    }
}